@@ -18,6 +18,7 @@
 
 from typing import List, Optional
 
+import hy
 import requests
 
 from raider.config import Config
@@ -124,7 +125,6 @@ class Flow:
                         item.get_value(pconfig)
                     output.get_value(pconfig)
 
-
     def run_operations(self) -> Optional[str]:
         """Runs the defined :class:`operations <raider.operations.Operation>`.
 
@@ -140,7 +140,11 @@ class Flow:
 
         if self.operations:
             for item in self.operations:
-                next_flow = item.run(self.pconfig, self.response)
+                if isinstance(item, hy.models.Expression):
+                    hy.eval(item)
+                else:
+                    next_flow = item.run(self.pconfig, self.response)
+
                 if next_flow or isinstance(next_flow, bool):
                     break
 
