@@ -1,4 +1,5 @@
 import argparse
+import sys
 
 from raider import Raider
 from raider.utils import list_projects
@@ -7,7 +8,8 @@ from raider.utils import list_projects
 def add_run_parser(parser) -> None:
     run_parser = parser.add_parser("run", help="Run Flow or Flowgraph")
     run_parser.add_argument("project", nargs="?", help="Project name")
-    run_parser.add_argument("flows",
+    run_parser.add_argument(
+        "flows",
         nargs="?",
         const="DEFAULT",
         default="DEFAULT",
@@ -31,12 +33,16 @@ def run_run_command(args: argparse.Namespace) -> None:
         raider.gconfig.use_proxy = True
 
     if not list_projects():
-        self.logger.critical(
+        raider.logger.critical(
             "No application have been configured. Cannot run!"
         )
         sys.exit()
 
-    raider.project.load()
+    if raider.project:
+        raider.project.load()
+    else:
+        raider.logger.critical(args.project + " doesn't exist. Cannot run!")
+        sys.exit()
 
     raider.run(args.flows, args.test)
 
